==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridClipboardEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescription } from "./WebGridClipboardEventDetailDescription";
/**
 * @hidden
 */
export let WebGridClipboardEventDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardEventDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardEventDetailDescriptionMetadata.a == null) {
                WebGridClipboardEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardEventDetailDescriptionMetadata.c(WebGridClipboardEventDetailDescriptionMetadata.a);
            }
            if (a.j(WebGridClipboardEventDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridClipboardEventDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardEventDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebGridClipboardEventDetailDescriptionMetadata.b(a);
            a.aa("WebGridClipboardEventDetail", () => new WebGridClipboardEventDetailDescription());
            a.z("WebGridClipboardEventDetail", WebGridClipboardEventDetailDescriptionMetadata.a);
        }
    }
    WebGridClipboardEventDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridClipboardEventDetailDescriptionMetadata, 'WebGridClipboardEventDetailDescriptionMetadata');
    WebGridClipboardEventDetailDescriptionMetadata.a = null;
    return WebGridClipboardEventDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridClipboardEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescription } from "./WebGridClipboardEventDetailDescription";
/**
 * @hidden
 */
export let WebGridClipboardEventDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardEventDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardEventDetailDescriptionMetadata.a == null) {
                WebGridClipboardEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardEventDetailDescriptionMetadata.c(WebGridClipboardEventDetailDescriptionMetadata.a);
            }
            if (a.k(WebGridClipboardEventDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridClipboardEventDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardEventDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebGridClipboardEventDetailDescriptionMetadata.b(a);
            a.ac("WebGridClipboardEventDetail", () => new WebGridClipboardEventDetailDescription());
            a.ab("WebGridClipboardEventDetail", WebGridClipboardEventDetailDescriptionMetadata.a);
        }
    }
    WebGridClipboardEventDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridClipboardEventDetailDescriptionMetadata, 'WebGridClipboardEventDetailDescriptionMetadata');
    WebGridClipboardEventDetailDescriptionMetadata.a = null;
    return WebGridClipboardEventDetailDescriptionMetadata;
})();
